import * as cdk from 'aws-cdk-lib';
import { Construct } from 'constructs';
/**
 * Well Architected Stack supports the following environments.
 */
export declare enum CkAccountType {
    DEVELOPMENT = "Dev",
    TEST = "Test",
    UAT = "Uat",
    PRODUCTION = "Prod"
}
/**
 * CloudKitect Stack Component Properties
 */
export interface CkStackProps extends cdk.StackProps {
    /**
       * Name of the application deployed by the stack
       */
    readonly ckApplication: string;
    /**
       * Company the application is associated with
       */
    readonly ckCompany: string;
    /**
       * AccountType where the stack will be deployed.
       */
    readonly ckAccountType: CkAccountType;
    /**
       * Any prefix for the stack name to avoid conflicts.
       * @defaultValue empty
       */
    readonly ckPrefix?: string;
    /**
     * Flag to control the removalPolicy override for the components
     * @default undefined, meaning it will use environment specific removal policy
     */
    readonly ckRemovalPolicyOverride?: cdk.RemovalPolicy;
}
/**
 * CloudKitect stack component that is environment aware and provides several methods
 * to find out the account type it is deployed so that other constructs can make decisions based on environments.
 *
 * ### Examples
 * Default Usage
 * ```ts
 * const stackProps = {
 *     ckApplication: 'ExampleApp',
 *     ckCompany: 'CloudKitect',
 *     ckAccountType: AccountType.UAT,
 *     env: {account: "ACCOUNT_ID", region: "us-east-1"}
 * }
 * new CkStack(app, "StackId", {
 *     ...stackProps
 * });
 * ```
 *
 * ### Compliance
 * It addresses the following compliance requirements
 * * 1. Cloudformation stacks in use for defining infrastructure
 *    >  - Risk Level: Medium
 *    >  - Compliance: APRA, MAS
 *    >  - Well Architected Pillar: Reliability, Operational Excellence
 */
export declare class CkStack extends cdk.Stack {
    /**
       * Get stack where the construct is deployed
       * @param construct
       */
    static findStackOf(construct: Construct): CkStack;
    static createStackId(id: string, prefix?: string): string;
    readonly removalPolicyOverride?: cdk.RemovalPolicy;
    constructor(scope: Construct, id: string, props: CkStackProps);
    /**
     * Removal policy is based on stack termination protection
     */
    removalPolicy(): cdk.RemovalPolicy;
    private envRemovalPolicy;
    /**
       * Account type where the stack is deployed
       */
    accountType(): CkAccountType;
    /**
       * Company name.
       */
    company(): string;
    /**
       * Application name.
       */
    applicationName(): string;
    /**
       * Find out if the stack is running in production account.
       */
    isProduction(): boolean;
    /**
       * Find out if the stack is running in development account.
       */
    isDevelopment(): boolean;
    /**
       * Find out if the stack is running in test account.
       */
    isTest(): boolean;
    /**
       * Find out if the stack is running in a non production account such as dev, test, uat
       */
    isNonProduction(): boolean;
    /**
       * Find out if the stack is running in uat account
       */
    isUAT(): boolean;
    /**
       * Find out if the stack is running in a production like environment such as uat and prod
       */
    isProductionLike(): boolean;
    /**
       * Find out if the stack is running in a development like environment such as dev or test
       */
    isDevelopmentLike(): boolean;
}
